==> mybb-1.4.10_1.tbz: www/mybb/inc/languages/english/admin/config_warning.lang.php <==
<?php
/**
 * MyBB 1.4 English Language Pack
 * Copyright  2008 MyBB Group, All Rights Reserved
 * 
 * $Id: config_warning.lang.php 4304 2009-01-02 01:11:56Z chris $
 */
 
$l['warning_system'] = "Warning System";
$l['warning_types'] = "Warning Types";
$l['warning_types_desc'] = "Here you can manage the list of different warning types staff are allowed to issue to users.";
$l['add_warning_type'] = "Add New Warning Type";
$l['add_warning_type_desc'] = "Here you can create a new predefined warning type. Warning types are selectable when warning users and you can define the number of points to add for this type as well as the time period before warnings of this type expire.";
$l['edit_warning_type'] = "Edit Warning Type";
$l['edit_warning_type_desc'] = "Here you can edit this warning type. Warning types are selectable when warning users and you can define the number of points to add for this type as well as the time period before warnings of this type expire.";
$l['warning_levels'] = "Warning Levels";
$l['warning_levels_desc'] = "Warning Levels define what happens to a user when they reach a particular warning level (percentage of maximum warning points). You can ban users or suspend their privileges.";
$l['add_warning_level'] = "Add New Warning Level";
$l['add_warning_level_desc'] = "Here you can create a new warning level. Warning levels are actions to be taken against users when they reach a specific percentage of the maximum warning level.";
$l['edit_warning_level'] = "Edit Warning Level";
$l['edit_warning_level_desc'] = "Warning levels are actions to be taken against users when they reach a specific percentage of the maximum warning level.";

$l['percentage'] = "Percentage";
$l['action_to_take'] = "Action to Take";
$l['move_banned_group'] = "Move to banned group ({1}) for {2} {3}";
$l['suspend_posting'] = "Suspend posting privileges for {1} {2}";
$l['moderate_new_posts'] = "Moderate new posts for {1} {2}";
$l['no_warning_levels'] = "There are no warning levels on your forum at this time.";

$l['warning_type'] = "Warning Type";
$l['points'] = "Points";
$l['expires_after'] = "Expires After";
$l['no_warning_types'] = "There are no warning types on your forum at this time.";

$l['warning_points_percentage'] = "Percentage of Maximum Warning Points";
$l['warning_points_percentage_desc'] = "Please enter a numeric value between 1 and 100.";
$l['action_to_be_taken'] = "Action to be Taken";
$l['action_to_be_taken_desc'] = "Select the action you wish to be taken when users reach the above level.";
$l['ban_user'] = "Ban User";
$l['banned_group'] = "Banned group:";
$l['ban_length'] = "Ban length:";
$l['suspend_posting_privileges'] = "Suspend Posting Privileges";
$l['suspension_length'] = "Suspension length:";
$l['moderate_posts'] = "Moderate Posts";
$l['moderation_length'] = "Moderation length:";
$l['save_warning_level'] = "Save Warning Level";

$l['title'] = "Title";
$l['points_to_add'] = "Points to Add";
$l['points_to_add_desc'] = "The number of points to add to a users warning level.";
$l['warning_expiry'] = "Warning Expiry";
$l['warning_expiry_desc'] = "How long after this warning is given do you want it to expire?";
$l['save_warning_type'] = "Save Warning Type";

$l['expiration_hours'] = "Hour(s)";
$l['expiration_days'] = "Day(s)";
$l['expiration_weeks'] = "Week(s)";
$l['expiration_months'] = "Month(s)";
$l['expiration_never'] = "Never";

$l['error_invalid_warning_level'] = "The specified warning level does not exist.";
$l['error_invalid_warning_percentage'] = "You did not enter a valid percentage value for this warning level. Your percentage value must be between 1 and 100.";
$l['error_invalid_warning_type'] = "The specified warning type does not exist.";
$l['error_missing_type_title'] = "You did not enter a title for this warning type";
$l['error_missing_type_points'] = "You did not enter a valid number of points to add when giving warnings of this type. You must enter a number greater than 0 but less than {1}";

$l['success_warning_level_created'] = "The warning level has been created successfully.";
$l['success_warning_level_updated'] = "The warning level has been updated successfully.";
$l['success_warning_level_deleted'] = "The selected warning level has been deleted successfully.";
$l['success_warning_type_created'] = "The warning type has been created successfully.";
$l['success_warning_type_updated'] = "The warning type has been updated successfully.";
$l['success_warning_type_deleted'] = "The selected warning type has been deleted successfully.";

$l['confirm_warning_level_deletion'] = "Are you sure you wish to delete this warning level?";
$l['confirm_warning_type_deletion'] = "Are you sure you wish to delete this warning type?";

?>

==> mybb-1.6.6.tbz: www/mybb/inc/languages/english/admin/config_warning.lang.php <==
<?php
/**
 * MyBB 1.6 English Language Pack
 * Copyright  2010 MyBB Group, All Rights Reserved
 * 
 * $Id: config_warning.lang.php 5297 2010-12-28 22:01:14Z Tomm $
 */
 
$l['warning_system'] = "Warning System";
$l['warning_types'] = "Warning Types";
$l['warning_types_desc'] = "Here you can manage the list of different warning types staff are allowed to issue to users.";
$l['add_warning_type'] = "Add New Warning Type";
$l['add_warning_type_desc'] = "Here you can create a new predefined warning type. Warning types are selectable when warning users and you can define the number of points to add for this type as well as the time period before warnings of this type expire.";
$l['edit_warning_type'] = "Edit Warning Type";
$l['edit_warning_type_desc'] = "Here you can edit this warning type. Warning types are selectable when warning users and you can define the number of points to add for this type as well as the time period before warnings of this type expire.";
$l['warning_levels'] = "Warning Levels";
$l['warning_levels_desc'] = "Warning Levels define what happens to a user when they reach a particular warning level (percentage of maximum warning points). You can ban users or suspend their privileges.";
$l['add_warning_level'] = "Add New Warning Level";
$l['add_warning_level_desc'] = "Here you can create a new warning level. Warning levels are actions to be taken against users when they reach a specific percentage of the maximum warning level.";
$l['edit_warning_level'] = "Edit Warning Level";
$l['edit_warning_level_desc'] = "Warning levels are actions to be taken against users when they reach a specific percentage of the maximum warning level.";

$l['percentage'] = "Percentage";
$l['action_to_take'] = "Action to Take";
$l['move_banned_group'] = "Move to banned group ({3}) for {1} {2}";
$l['move_banned_group_permanent'] = "Move to banned group ({1}) Permanently";
$l['suspend_posting'] = "Suspend posting privileges for {1} {2}";
$l['suspend_posting_permanent'] = "Suspend posting privileges Permanently";
$l['moderate_new_posts'] = "Moderate new posts for {1} {2}";
$l['moderate_new_posts_permanent'] = "Moderate new posts Permanently";
$l['no_warning_levels'] = "There are no warning levels on your forum at this time.";

$l['warning_type'] = "Warning Type";
$l['points'] = "Points";
$l['expires_after'] = "Expires After";
$l['no_warning_types'] = "There are no warning types on your forum at this time.";

$l['warning_points_percentage'] = "Percentage of Maximum Warning Points";
$l['warning_points_percentage_desc'] = "Please enter a numeric value between 1 and 100.";
$l['action_to_be_taken'] = "Action to be Taken";
$l['action_to_be_taken_desc'] = "Select the action you wish to be taken when users reach the above level.";
$l['ban_user'] = "Ban User";
$l['banned_group'] = "Banned group:";
$l['ban_length'] = "Ban length:";
$l['suspend_posting_privileges'] = "Suspend Posting Privileges";
$l['suspension_length'] = "Suspension length:";
$l['moderate_posts'] = "Moderate Posts";
$l['moderation_length'] = "Moderation length:";
$l['save_warning_level'] = "Save Warning Level";

$l['title'] = "Title";
$l['points_to_add'] = "Points to Add";
$l['points_to_add_desc'] = "The number of points to add to a users warning level.";
$l['warning_expiry'] = "Warning Expiry";
$l['warning_expiry_desc'] = "How long after this warning is given do you want it to expire?";
$l['save_warning_type'] = "Save Warning Type";

$l['expiration_hours'] = "Hour(s)";
$l['expiration_days'] = "Day(s)";
$l['expiration_weeks'] = "Week(s)";
$l['expiration_months'] = "Month(s)";
$l['expiration_never'] = "Never";
$l['expiration_permanent'] = "Permanent";

$l['error_invalid_warning_level'] = "The specified warning level does not exist.";
$l['error_invalid_warning_percentage'] = "You did not enter a valid percentage value for this warning level. Your percentage value must be between 1 and 100.";
$l['error_invalid_warning_type'] = "The specified warning type does not exist.";
$l['error_missing_type_title'] = "You did not enter a title for this warning type";
$l['error_missing_type_points'] = "You did not enter a valid number of points to add when giving warnings of this type. You must enter a number greater than 0 but less than {1}";

$l['success_warning_level_created'] = "The warning level has been created successfully.";
$l['success_warning_level_updated'] = "The warning level has been updated successfully.";
$l['success_warning_level_deleted'] = "The selected warning level has been deleted successfully.";
$l['success_warning_type_created'] = "The warning type has been created successfully.";
$l['success_warning_type_updated'] = "The warning type has been updated successfully.";
$l['success_warning_type_deleted'] = "The selected warning type has been deleted successfully.";

$l['confirm_warning_level_deletion'] = "Are you sure you wish to delete this warning level?";
$l['confirm_warning_type_deletion'] = "Are you sure you wish to delete this warning type?";

?>
